@@ -5,4 +5,4 @@ from styler_rest_framework.pubsub.publishers import publisher_for_message
 from styler_rest_framework.config import defaults
 
 
-send_email = publisher_for_message(SendMailMessage, defaults.TOPIC_NAME)
+send_email = publisher_for_message(SendMailMessage, defaults.MAILER_TOPIC)
