@@ -5,11 +5,9 @@ import json
 
 
 class Message:
-    """ Base message
-    """
+    """Base message"""
 
     def encoded(self):
-        """ Return a encoded data for pub sub
-        """
+        """Return a encoded data for pub sub"""
         json_string = json.dumps(self, default=lambda o: o.__dict__, indent=4)
-        return json_string.encode('utf-8')
+        return json_string.encode("utf-8")
